<?php declare(strict_types=1);

namespace Drupal\group_clone\Entity;

use Drupal\Core\Config\Entity\ConfigEntityBase;

/**
 * Defines the group_clone_settings config entity type.
 *
 * @ConfigEntityType(
 *   id = "group_clone_settings",
 *   label = @Translation("Group clone settings"),
 *   config_prefix = "group_clone",
 *   admin_permission = "administer group",
 *   entity_keys = {
 *     "id" = "id",
 *     "uuid" = "uuid",
 *   },
 *   config_export = {
 *     "id",
 *     "status",
 *     "content_types",
 *   },
 * )
 */
final class GroupCloneSettings extends ConfigEntityBase {

  /**
   * The group type ID.
   */
  protected ?string $id;

  /**
   * Content types clone settings.
   *
   * @var mixed[]
   */
  protected array $content_types;

  /**
   * {@inheritdoc}
   */
  public function calculateDependencies(): self {
    parent::calculateDependencies();

    $group_type = $this->entityTypeManager()
      ->getStorage('group_type')
      ->load($this->id);
    $this->addDependency('config', $group_type->getConfigDependencyName());

    foreach ($this->content_types as $group_content_type_id => $value) {
      if ($value !== 0) {
        $group_content_type = $this->entityTypeManager()
          ->getStorage('group_content_type')
          ->load($group_content_type_id);
        if ($group_content_type) {
          $this->addDependency('config', $group_content_type->getConfigDependencyName());
        }
      }
    }

    return $this;
  }

  /**
   * Check if settings are empty.
   */
  public function empty(): bool {
    if ($this->status) {
      return FALSE;
    }

    $empty = TRUE;
    foreach ($this->content_types as $value) {
      if ($value !== 0) {
        $empty = FALSE;
      }
    }

    return $empty;
  }

}
