<?php

declare(strict_types=1);

namespace Drupal\group_clone\Form;

use Drupal\group\Entity\GroupTypeInterface;
use Drupal\group\Entity\Storage\GroupContentTypeStorageInterface;
use Drupal\group_clone\Entity\GroupCloneSettings;

trait GroupCloneFormTrait {

  private array $settings = [];

  /**
   * Helper function to get settings entity for group type.
   */
  private function getConfigEntity(string $id): GroupCloneSettings {
    if (!array_key_exists($id, $this->settings)) {
      $group_clone_settings_storage = $this->entityTypeManager->getStorage('group_clone_settings');
      $this->settings[$id] = $group_clone_settings_storage->load($id);
      if (!$this->settings[$id] instanceof GroupCloneSettings) {
        $this->settings[$id] = $group_clone_settings_storage->create([
          'id' => $id,
          'status' => FALSE,
          'content_types' => [],
        ]);
      }
    }
    return $this->settings[$id];
  }

  /**
   * Get cloning settings form element for a single group type.
   */
  private function getGroupTypeSettingsElement(GroupContentTypeStorageInterface $group_content_type_storage, GroupTypeInterface $group_type, GroupCloneSettings $config): array {
    $element = [
      '#type' => 'fieldset',
      '#title' => t('Content type settings'),
      '#tree' => TRUE,
    ];

    $content_type_settings = $config->get('content_types');
    foreach ($group_content_type_storage->loadByGroupType($group_type) as $group_content_type) {
      $type_id = $group_content_type->id();
      $element[$type_id] = [
        '#type' => 'radios',
        '#title' => $group_content_type->label(),
        '#options' => [
          'disabled' => $this->t('Cloning disabled'),
          'references' => $this->t('References only'),
          'all' => $this->t('References and entities'),
        ],
        '#default_value' => \array_key_exists($type_id, $content_type_settings) ? $content_type_settings[$type_id] : 'disabled',
      ];
    }

    return $element;
  }

}
